simhash
===========

This is a Python implementation of [Simhash](http://www.wwwconference.org/www2007/papers/paper215.pdf).

## Getting Started

<http://leons.im/posts/a-python-implementation-of-simhash-algorithm/>

## Build Status

[![Build Status](https://travis-ci.org/leonsim/simhash.png?branch=master)](https://travis-ci.org/leonsim/simhash)
